; --------------------------------------------------------------------------
;  RMB167-CRI examples
;
; -- FOR INTERNAL USE ONLY --
;
;  (C) 1996 by Rigel Corporation
;  All Rights Reserved.
;
;  P.O. Box 90040 
;  Gainesville, FL, 32607
;
;  Tel: (352) 373-4629
;  http://www.rigelcorp.com/
;
;
; --------------------------------------------------------------------------
; Hello World Example
;
; Description:  Run from FLASH EEPROMM
;
;
; Burn this code into EEPROM.  Switch the CS0# and CS1# jumpers so that 
; CS0# activates ROM, and CS1# activates RAM.  Remove P0.4 so that the 
; bootstrap loader is disabled.  Press RESET and observe the message. 
;
; --------------------------------------------------------------------------
; constants:
      CR      equ    13
      LF      equ    10
; --------------------------------------------------------------------------

      org      0                ; reset vector
      jmpa     cc_UC, STARTUP

      org      200h
STARTUP:
; --- initialization phase ---
       mov     SYSCON, #0F480h
       nop
       mov     SYSCON, #0F480h
       nop
; --- initialize CPS --------------------------------------------------------
       jmps    0, next1
next1:
; --- initialize DPPx -------------------------------------------------------
       mov     DPP0, #0
       mov     DPP1, #1
       mov     DPP2, #2
       mov     DPP3, #3
; --- initialize PSW and execute the RETI to end the NMI trap state --------
       mov     PSW, #0           ; set IVLV = 0
       bclr    NMI               ; clear NMI flag
       mov     r0, #0
       push    r0
       push    r0
       mov     r0, #next2
       push    r0                ; push address of next2 on stack         
       reti                      ; program will continue fron next2
next2:
; --- initialize stack and contex pointers ----------------------------------
       mov     CP, #0FC00h
       mov     SP, #0FC00h
       mov     STKOV, #0FA00h
       mov     STKUN, #0FC00h
; --- set up WR# as an output -----------------------------------------------
       bset    P3.13             ; set WR#
       bset    DP3.13            ; make WR# an output
; --- setup ADDRSEL1 --------------------------------------------------------
; ADDRSEL1 is now associated with RAM.  Let's have the first 32K 
; memory in FLASH EEPROM and the next 32K in RAM.  
; CS1# is active from 8000h to FFFFh

       mov     ADDRSEL1, #83h    ; start at 32K, size 32K
       mov     BUSCON1, #680h    ; RAM

; --- set up serial port ----------------------------------------------------
       bset    DP3.10
       mov     S0CON, #8011h
       mov     S0BG, #3Fh
       mov     S0TIC, #0
       mov     S0RIC, #0
       mov     S0EIC, #0
; --- serial port initialized for 40MHz oscillator frequency ---

       DISWDT
       EINIT
; --- initialization done ---------------------------------------------------
       

; --- send message ----------------------------------------------------------
LOOP:
      mov     r1, #msgHello
      calla   cc_UC, print
      calla   cc_UC, getchr     ; wait for a character...
      jmpa    cc_UC, LOOP       ; endless loop

; --------------------------------------------------------------------------
; --- support routines ---
; --------------------------------------------------------------------------
GETCHR:
        jnb     S0RIR, getchr
        mov     r0, S0RBUF
        bclr    S0RIR
        ret
; --------------------------------------------------------------------------
SNDCHR:
        mov     S0TBUF, r0
sndchr1:
        jnb     S0TIR, sndchr1
        bclr    S0TIR
        ret
; --------------------------------------------------------------------------
PRINT:
prt1:
        movb    rl0, [r1]
        cmpb    rl0, #(DATA16 0)
        jmpr    cc_EQ, prt2
        calla   cc_UC, sndchr
        add     r1, #(DATA16 1)
        jmpr    cc_UC, prt1
prt2:
        ret
; --------------------------------------------------------------------------



; --------------------------------------------------------------------------
; variables and message definitions
; --------------------------------------------------------------------------
EVEN
msgHello:
         db     CR, LF, "Hello world from the EEPROMs...", 0
EVEN
; --------------------------------------------------------------------------
; end of program...
; --------------------------------------------------------------------------
